# Building Initializer

This package copies and enriches building data from an OpenStreetMap replication database.
For this, the predefined rules in `rule-lib` are executed.

# Usage with Docker
A minimal Docker setup needs a docker-compose file, a `.env` file, a definition of rules and
a configuration file for the database connections. The file structure could look like:
```
├── data
│ ├── rules
│ │ ├── storeys.zip
│ │ └── geometry.zip
│ └── config.yml
├── .env
└── docker-compose.yml
```

The `docker-compose.yml` specifies the Docker container and the locations of the files. All
files that are in `./data` are copied to the location `/app/data` in the docker container,
therefore they should be references as such in the `.env` file.
```yaml
version: '3.3'

services:
    building-initializer:
        build: https://git.gfz-potsdam.de/globaldynamicexposure/building-initializer.git
        volumes:
          - ./data:/app/data
        env_file: .env
```

The `.env` file contains the parameters that are used to execute the python file:
```
DATABASE_CONFIG_FILE=/app/data/config.yml
RULES_PATTERN=/app/data/rules/*.xml
BATCH_SIZE=500
NUM_PROCESSORS=10
BUILDING_TABLE=google_buildings  # Optional, standard: `obm_buildings`
BUILDING_ID_COLUMN=id  # Optional, standard: `osm_id`
BUILDING_GEOMETRY_COLUMN=geom  # Optional, standard: `geometry`
CUSTOM_SQL_STATEMENT=SELECT id FROM google_buildings  # Optional, standard: all features
```

The `config.yml` file contains the connection parameters to the source and building databases:
```yaml
source_db:
  host: localhost  # host (name or IP address) needs to be accessible from inside the docker container.
  dbname: source_db
  port: 5432
  username: user
  password: pass

building_db:
  host: localhost
  dbname: building_db
  port: 5432
  username: user
  password: pass

source_building_db:  # Not needed for initializing OpenStreetMap buildings
  host: localhost
  dbname: building_db
  port: 5432
  username: user
  password: pass
```

## Releases

| Version | Description                                                                      |
|---------|----------------------------------------------------------------------------------|
| 0.1.0   | First release of building-initializer. Works only with OSM buildings             |
| 0.2.0   | Any generalized building dataset can be initialized with the BuildingInitializer |


## How to install
First, the package registry needs to be added to the pip index urls, so the package (and its dependencies) can be found.
Afterwards, `building-initializer` can be installed with pip.

```
pip config set global.extra-index-url https://git.gfz-potsdam.de/api/v4/projects/2940/packages/pypi/simple
pip install buildinginitializer
```


## Copyright and copyleft 

Copyright (C) 2023

* Helmholtz-Zentrum Potsdam Deutsches GeoForschungsZentrum GFZ

This program is free software: you can redistribute it and/or modify it
under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or (at
your option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero
General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with this program. If not, see http://www.gnu.org/licenses/.

Also add information on how to contact you by electronic and paper mail.

If your software can interact with users remotely through a computer
network, you should also make sure that it provides a way for users to
get its source. For example, if your program is a web application, its
interface could display a "Source" link that leads users to an archive
of the code. There are many ways you could offer source, and different
solutions will be better for different programs; see section 13 for the
specific requirements.

See the [LICENSE](./LICENSE) for the full license text.
